/*
Copyright The Helm Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package helm_v3

import (
	"io"

	"github.com/spf13/cobra"

	"github.com/werf/3p-helm-for-werf-helm/cmd/helm/require"
	"github.com/werf/3p-helm-for-werf-helm/pkg/action"
)

const registryLogoutDesc = `
Remove credentials stored for a remote registry.
`

func newRegistryLogoutCmd(cfg *action.Configuration, out io.Writer) *cobra.Command {
	return &cobra.Command{
		Use:               "logout [host]",
		Short:             "logout from a registry",
		Long:              registryLogoutDesc,
		Args:              require.MinimumNArgs(1),
		ValidArgsFunction: noCompletions,
		RunE: func(cmd *cobra.Command, args []string) error {
			hostname := args[0]
			return action.NewRegistryLogout(cfg).Run(out, hostname)
		},
	}
}
